@@ -19,6 +19,7 @@
 #include "spanner.hh"
 #include "item.hh"
 
+
 MAKE_SCHEME_CALLBACK (Hyphen_spanner,set_spacing_rods,1);
 SCM
 Hyphen_spanner::set_spacing_rods (SCM smob)
@@ -59,7 +60,7 @@ Hyphen_spanner::brew_molecule (SCM smob)
     {
       Interval iv = sp->get_bound (d)->extent (common, X_AXIS);
 
-      bounds[d] = iv.empty_b ()
+      bounds[d] = iv.is_empty ()
 	? sp->get_bound (d)->relative_coordinate (common, X_AXIS)
 	: iv[-d];
     }
@@ -91,7 +92,7 @@ Hyphen_spanner::brew_molecule (SCM smob)
     we should probably do something more intelligent when bounds is
     empty, but at least this doesn't crash.
   */      
-  Real w  = bounds.empty_b () ? 0 : bounds.length ();
+  Real w  = bounds.is_empty () ? 0 : bounds.length ();
   
   /* for length, use a geometric mean of the available space and some minimum
    */
@@ -125,7 +126,7 @@ Hyphen_spanner::brew_molecule (SCM smob)
     }
   Box b (Interval (-l/2,l/2), Interval (h,h+th));
   Molecule mol (Lookup::filledbox (b));
-  Real ct = bounds.empty_b () ? 0 : bounds.center () ;
+  Real ct = bounds.is_empty () ? 0 : bounds.center () ;
   mol.translate_axis (ct -sp->relative_coordinate (common, X_AXIS), X_AXIS);
   return mol.smobbed_copy ();
 }
@@ -145,8 +146,6 @@ Hyphen_spanner::Hyphen_spanner (Spanner*s)
 
 
 ADD_INTERFACE (Hyphen_spanner, "lyric-hyphen-interface",
-  "A centred hyphen is a simple line between lyrics used to divide "
-"syllables.   The length of the hyphen line should stretch based on the "
-"size of the gap between syllables.",
-  "thickness height minimum-length maximum-length word-space");
+	       "A centred hyphen is a simple line between lyrics used to divide syllables",
+	       "thickness height minimum-length maximum-length word-space");
 
