@@ -4,66 +4,65 @@
   source file of the GNU LilyPond music typesetter
   
   (c) 2000--2003 Han-Wen Nienhuys <hanwen@cs.uu.nl>, Glen Prideaux <glenprideaux@iname.com>
-  
-  Similar to (and derived from) Instrument_name_engraver.
- */
+
+*/
 
 #include "engraver.hh"
 #include "item.hh"
-#include "bar-line.hh"
+#include "side-position-interface.hh"
 
 class Stanza_number_engraver : public Engraver
 {
   Item *text_;
-  bool bar_b_;
 
-  void create_text (SCM s);
+  /*
+    This is naughty, since last_stanza_ may be GCd from under us.  But
+    since we don't look at the contents, we are/should be (knock on
+    wood) OK.
+   */
+  SCM last_stanza_;
 public:
   TRANSLATOR_DECLARATIONS(Stanza_number_engraver);
-
   virtual void process_music ();
   virtual void stop_translation_timestep ();
+  virtual void acknowledge_grob (Grob_info);
 };
 
 
+/*
+  TODO: should make engraver that collects all the stanzas on a higher
+  level, and then groups them to the side. Stanza numbers should be
+  all aligned.
+ */
 
 Stanza_number_engraver::Stanza_number_engraver ()
 {
   text_ = 0;
-  bar_b_ = false;
 }
 
 void
 Stanza_number_engraver::process_music ()
 {
-  if (gh_string_p (get_property ("whichBar")))
+  SCM stanza = get_property ("stanza");
+  
+  if (gh_string_p (stanza) && stanza != last_stanza_)
     {
-      SCM s = get_property ("stanza");
+      last_stanza_ = stanza;
       
-      if (now_mom () > Moment (0))
-	s = get_property ("stz");
+      text_ = new Item (get_property ("StanzaNumber"));
+      text_->set_grob_property ("text", stanza);
+      announce_grob (text_, SCM_EOL);
+    }
+}
 
 
-      // TODO
-      if (gh_string_p (s) || gh_pair_p (s))
-
-	/*
-	  if (i.grob_->internal_has_interface (symbol ("lyric-syllable-interface")))
-
-	  Tried catching lyric items to generate stanza numbers, but it
-	  spoils lyric spacing.
-
-	  Works, but requires bar_engraver in LyricsVoice context apart
-	  from at beginning.  Is there any score element we can catch
-	  that will do the trick?
-
-	  What happens if we try anything at all EXCEPT a lyric? Is
-	  there anything else?  Not sure what it's catching, but it
-	  still mucks up lyrics.
-
-	*/
-
-	create_text (s);
+void
+Stanza_number_engraver::acknowledge_grob (Grob_info inf)
+{
+  if (text_
+      && inf.grob_->internal_has_interface (ly_symbol2scm ("lyric-text-interface")))
+    {
+      Side_position_interface::add_support (text_, inf.grob_);
     }
 }
 
@@ -77,24 +76,11 @@ Stanza_number_engraver::stop_translation_timestep ()
     }
 }
 
-void
-Stanza_number_engraver::create_text (SCM txt)
-{
-  if (!text_)
-    {
-      text_ = new Item (get_property ("StanzaNumber"));
-      text_->set_grob_property ("text", txt);
-      announce_grob (text_, SCM_EOL);
-    }
-}
-
-
-
 
 ENTER_DESCRIPTION(Stanza_number_engraver,
 /* descr */       "",
 /* creats*/       "StanzaNumber",
 /* accepts */     "",
-/* acks  */      "",
-/* reads */       "stz stanza",
+/* acks  */      "lyric-syllable-interface",
+/* reads */       "stanza",
 /* write */       "");
