@@ -259,7 +259,7 @@ Stem::get_default_dir (Grob*me)
 {
   int staff_center = 0;
   Interval hp = head_positions (me);
-  if (hp.empty_b())
+  if (hp.is_empty ())
     {
       return CENTER;
     }
@@ -356,7 +356,7 @@ Stem::get_default_stem_end_position (Grob*me)
       if (durlog >= 3)
 	{
 	  Interval flag_ext = flag (me).extent (Y_AXIS) ;
-	  if (!flag_ext.empty_b())
+	  if (!flag_ext.is_empty ())
 	    minlen += 2 * flag_ext.length () / ss ;
 
 	  /*
@@ -646,7 +646,7 @@ Stem::flag (Grob*me)
     flag_style + to_string (dir) + staffline_offs + to_string (duration_log (me));
   Font_metric *fm = Font_interface::get_default_font (me);
   Molecule flag = fm->find_by_name ("flags-" + font_char);
-  if (flag.empty_b ())
+  if (flag.is_empty ())
     {
       me->warning (_f ("flag `%s' not found", font_char));
     }
@@ -655,11 +655,11 @@ Stem::flag (Grob*me)
   if (gh_string_p (stroke_style_scm))
     {
       String stroke_style = ly_scm2string (stroke_style_scm);
-      if (!stroke_style.empty_b ())
+      if (!stroke_style.is_empty ())
 	{
 	  String font_char = to_string (dir) + stroke_style;
 	  Molecule stroke = fm->find_by_name ("flags-" + font_char);
-	  if (stroke.empty_b ())
+	  if (stroke.is_empty ())
 	    {
 	      me->warning (_f ("flag stroke `%s' not found", font_char));
 	    }
@@ -737,7 +737,7 @@ Stem::brew_molecule (SCM smob)
 	must not take ledgers into account.
        */
       Interval head_height = Note_head::head_extent (hed,Y_AXIS);
-      Real y_attach = Note_head::stem_attachment_coordinate ( hed, Y_AXIS);
+      Real y_attach = Note_head::stem_attachment_coordinate (hed, Y_AXIS);
 
       y_attach = head_height.linear_combination (y_attach);
       stem_y[Direction (-d)] += d * y_attach/dy;
@@ -786,7 +786,6 @@ Stem::off_callback (SCM element_smob, SCM)
   if (Grob * f = first_head (me))
     {
       Interval head_wid = Note_head::head_extent(f, X_AXIS);
-
       
       Real attach =0.0;
 
@@ -811,7 +810,6 @@ Stem::off_callback (SCM element_smob, SCM)
 	  Real rule_thick
 	    = gh_scm2double (me->get_grob_property ("thickness"))
 	    * me->get_paper ()->get_realvar (ly_symbol2scm ("linethickness"));
-
 	  
 	  r += - d * rule_thick * 0.5;
 	}
@@ -819,6 +817,7 @@ Stem::off_callback (SCM element_smob, SCM)
   return gh_double2scm (r);
 }
 
+
 Grob*
 Stem::get_beam (Grob*me)
 {
