@@ -378,7 +378,6 @@ as a real penalty.")
 			   "Remove the first staff of a orchestral score?")
 (grob-property-description 'right-padding ly:dimension? "space right of accs.")
 (grob-property-description 'right-position number? "position of right part of spanner.")
-(grob-property-description 'right-trim-amount ly:dimension? "shortening of the lyric extender on the right.")
 (grob-property-description 'script-priority number? "A sorting key that determines in what order a script is within a stack of scripts.")
 (grob-property-description 'self-alignment-X number-or-grob? "real number: -1 =
 left aligned, 0 = center, 1 right-aligned in X direction.
@@ -421,10 +420,12 @@ itself.  Return value is ignored.")
 
 (grob-property-description 'staffline-clearance ly:dimension? "don't get closer than this to stafflines.")
 (grob-property-description 'stem ly:grob? "pointer to Stem object.")
+
 (grob-property-description 'stem-attachment-function procedure? "Where
-does the stem attach to the notehead? Function takes a symbol argument
-being the style. It returns a (X . Y) pair, specifying location in
-terms of note head bounding box.")
+does the stem attach to the notehead? Function takes grob and axis as
+arguments. It returns a (X . Y) pair, specifying location in terms of
+note head bounding box.")
+
 (grob-property-description 'stem-end-position number? "Where does the stem end (the end is opposite to the support-head.")
 
 (grob-property-description 'stem-shorten list? "shorten stems in forced directions given flag multiplicity:
@@ -464,10 +465,6 @@ containing (TRANSPARENT . EMPTY).
 (grob-property-description 'when ly:moment? "when does this column happen?.")
 (grob-property-description 'word-space ly:dimension? "elongate left (?) by this much (FIXME: cumbersome semantics).")
 
-(grob-property-description 'alignment number? "alignment of lyrics on notehead, -1 is LEFT, 0 is CENTRE, 1 is RIGHT .")
-(grob-property-description 'ignore-length-mismatch boolean? "if #t, stanzas with shorter lyrics can be moved away from their respective note-head by the lyric alignment code.")
-(grob-property-description 'begin-alignment number? "proportion of lyric length from beginning to align with note-head for left-aligned lyrics.")
-(grob-property-description 'end-alignment number? "proportion of lyric length from end to align with note-head for right-aligned lyrics.")
 (grob-property-description 'width ly:dimension? "width of a grob measured in staff space.")
 (grob-property-description 'width-correct ly:dimension? "width correction for (de)cresc. text spanners.")
 (grob-property-description 'x-gap ly:dimension? "horizontal gap between notehead and tie.")
