@@ -228,7 +228,7 @@
 	(break-align-symbol . clef)
 	(break-visibility . ,begin-of-line-visible)
 	(space-alist . ((ambitus . (extra-space . 2.0))
-			(staff-bar . (minimum-space .  3.7))
+			(staff-bar . (extra-space . 0.7))
 			(key-signature . (minimum-space . 4.0))
 			(time-signature . (minimum-space . 4.2))
 			(first-note . (minimum-space . 5.0))
@@ -481,22 +481,16 @@
     (LyricExtender
      . (
 	(molecule-callback . ,Lyric_extender::brew_molecule)
-	(height . 0.8) ; stafflinethickness;
-	(right-trim-amount . 0.5)
+	(thickness . 0.8) ; stafflinethickness;
 	(Y-extent-callback . ,Grob::point_dimension_callback)
 	(meta . ((interfaces . (lyric-extender-interface spanner-interface))))
 	))
 
     (LyricText
-     . (
-	(molecule-callback . ,Text_item::brew_molecule)
-	(X-offset-callbacks . (,Self_alignment_interface::centered_on_parent
-			       ,Self_alignment_interface::aligned_on_self))
+     . ((molecule-callback . ,Text_item::brew_molecule)
+	(X-offset-callbacks . (,Self_alignment_interface::aligned_on_parent))
 	(self-alignment-X . 0)
 	(word-space . 0.6)
-	(ignore-length-mismatch . #f)
-	(begin-alignment . 4)
-	(end-alignment . 2)
 	(font-family . roman)
 	(font-shape . upright)
 	
@@ -850,13 +844,13 @@
 	))
 
     (StanzaNumber
-     . (
-	(breakable . #t)
-	(molecule-callback . ,Text_item::brew_molecule)		
-	(break-align-symbol . clef)
-	(break-visibility . ,begin-of-line-visible)
+     . ((molecule-callback . ,Text_item::brew_molecule)		
 	(font-family . roman)
-	(meta . ((interfaces . (break-aligned-interface text-interface font-interface item-interface ))))		
+	(font-series . bold)
+	(padding . 1.5)
+	(X-offset-callbacks . (,Side_position_interface::aligned_side))
+	(direction . ,LEFT) 
+	(meta . ((interfaces . (side-position-interface text-interface font-interface item-interface ))))		
 	))
 
     (StaffSpacing
